@@ -17,7 +17,7 @@ class VulnerabilityManagementGateway(metaclass=ABCMeta):
         "get_findings_excepted"
 
     @abstractmethod
-    def get_all_findings(
+    def get_all(
         self, service, dict_args, secret_tool, config_tool
     ):
-        "get_report"
+        "get all findings and exclusions from vulnerability management platform"
